Index: trunk/ippTools/src/chiptool.c
===================================================================
--- trunk/ippTools/src/chiptool.c	(revision 14018)
+++ trunk/ippTools/src/chiptool.c	(revision 14023)
@@ -132,6 +132,6 @@
 
     psMetadata *where = psMetadataAlloc();
-    ADDPARAMSTR(config->args, where, "exp_tag");
     ADDPARAMSTR(config->args, where, "exp_id");
+    ADDPARAMSTR(config->args, where, "exp_name");
     ADDRENAMEPARAMSTR(config->args, where, "inst", "camera");
     ADDPARAMSTR(config->args, where, "telescope");
@@ -190,5 +190,5 @@
     }
 
     // find the exp_tag of all the exposures that we want to queue up.
     psString query = pxDataGet("chiptool_find_rawexp.sql");
     if (!query) {
@@ -230,11 +230,11 @@
     }
 
-    // loop over our list of exp_tags
+    // loop over our list of exp_ids
     for (long i = 0; i < psArrayLength(output); i++) {
         psMetadata *md = output->data[i];
 
-        psString exp_tag = psMetadataLookupStr(&status, md, "exp_tag");
+        psString exp_id = psMetadataLookupStr(&status, md, "exp_id");
         if (!status) {
-            psError(PS_ERR_UNKNOWN, false, "failed to lookup value for exp_tag");
+            psError(PS_ERR_UNKNOWN, false, "failed to lookup value for exp_id");
             psFree(output);
             return false;
@@ -242,10 +242,10 @@
 
         // queue the exp
-        if (!pxchipQueueByExpTag(config, exp_tag, workdir, label, reduction, expgroup, dvodb)) {
+        if (!pxchipQueueByExpTag(config, exp_id, workdir, label, reduction, expgroup, dvodb)) {
             if (!psDBRollback(config->dbh)) {
                 psError(PS_ERR_UNKNOWN, false, "database error");
             }
             psError(PS_ERR_UNKNOWN, false,
-                    "failed to trying to queue exp_tag: %s", exp_tag);
+                    "failed to trying to queue exp_id: %s", exp_id);
             psFree(output);
             return false;
@@ -357,11 +357,11 @@
     }
 
-    psString exp_tag = psMetadataLookupStr(&status, config->args, "-exp_tag");
-    if (!status) {
-        psError(PS_ERR_UNKNOWN, false, "failed to lookup value for -exp_tag");
-        return false;
-    }
-    if (!exp_tag) {
-        psError(PS_ERR_UNKNOWN, true, "-exp_tag is required");
+    psString exp_id = psMetadataLookupStr(&status, config->args, "-exp_id");
+    if (!status) {
+        psError(PS_ERR_UNKNOWN, false, "failed to lookup value for -exp_id");
+        return false;
+    }
+    if (!exp_id) {
+        psError(PS_ERR_UNKNOWN, true, "-exp_id is required");
         return false;
     }
@@ -511,6 +511,6 @@
 
     chipProcessedImfileRow *imfile = chipProcessedImfileRowAlloc(
-        (psU64)atoll(chip_id),
-        exp_tag,
+        (psS64)atoll(chip_id),
+        (psS64)atoll(exp_id),
         class_id,
         uri,
@@ -190,5 +190,5 @@
     }
 
-    // find the exp_tag of all the exposures that we want to queue up.
+    // find the exp_id of all the exposures that we want to queue up.
     psString query = pxDataGet("chiptool_find_rawexp.sql");
     if (!query) {
